pub struct BytesWrapper<T, O> {
inner: T,
phantom: PhantomData<O>,
}Expand description
Wraps a type T that uses the byte array serde data type for serialization so
that the serde string data type is used instead,
according to BytesEncoding O::Encoding.
Due to the generic (de)serialize implementation, the standard types
Vec<u8>, &[u8], [u8,N], … use the sequence serde data type instead of byte array.
Use serde_bytes::Bytes, serde_bytes::ByteBuf, and ByteArray instead.
(Or use ChangeVisitorType to change the visitor type to VisitorType::ByteSequence.)
We primarily use this to encode keys as hex or base64 strings in JSON instead of arrays.
Fields
inner: Tphantom: PhantomData<O>Implementations
Sourceimpl<T, O> BytesWrapper<T, O>
impl<T, O> BytesWrapper<T, O>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Returns the wrapped object.
Note: We cannot implement Into<T> for BytesWrapper, because it would clash
with the implementation of Into<T> when T implements From<BytesWrapper>.
pub fn new(inner: T) -> Self